%bcond_with bootstrap

Summary:          Generate and interpret ANSI escape sequences in Java
Name:             jansi
Version:          2.4.0
Release:          4%{?dist}
License:          ASL 2.0
URL:              http://fusesource.github.io/jansi/
Source0:          https://github.com/fusesource/jansi/archive/%{name}-%{version}.tar.gz

Patch3000:        %{name}-jni.patch

BuildRequires:    gcc
%if %{with bootstrap}
BuildRequires:    javapackages-bootstrap
%else
BuildRequires:    maven-local
BuildRequires:    mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:    mvn(org.apache.maven.plugins:maven-source-plugin)
BuildRequires:    mvn(org.apache.maven.surefire:surefire-junit-platform)
BuildRequires:    mvn(org.fusesource:fusesource-pom:pom:)
BuildRequires:    mvn(org.junit.jupiter:junit-jupiter-engine)
%endif

%description
Jansi is a small java library that allows you to use ANSI escape sequences
in your Java console applications. It implements ANSI support on platforms
which don't support it like Windows and provides graceful degradation for
when output is being sent to output devices which cannot support ANSI sequences.

%package javadoc
Summary:          Javadocs for %{name}
BuildArch:        noarch

%description javadoc
This package contains the API documentation for %{name}.

%prep
%autosetup -n jansi-jansi-%{version} -p1

%pom_xpath_remove "pom:build/pom:extensions"

%pom_remove_plugin :maven-gpg-plugin
%pom_remove_plugin :maven-javadoc-plugin
%pom_remove_plugin :nexus-staging-maven-plugin

%pom_remove_plugin :exec-maven-plugin
%pom_remove_dep :picocli-codegen

%pom_xpath_set "//pom:properties/pom:jdkTarget" 1.8

rm -fr src/main/resources/org/fusesource/jansi/internal

rm src/main/native/inc_linux/*.h
ln -s %{java_home}/include/jni.h src/main/native/inc_linux
ln -s %{java_home}/include/linux/jni_md.h src/main/native/inc_linux

sed -i 's,@LIBDIR@,%{_prefix}/lib,' \
    src/main/java/org/fusesource/jansi/internal/JansiLoader.java

%build
CC="${CC:-gcc}"
CFLAGS="$CFLAGS -I. -I%{java_home}/include -I%{java_home}/include/linux -fPIC -fvisibility=hidden"
cd src/main/native
$CC $CFLAGS -c jansi.c
$CC $CFLAGS -c jansi_isatty.c
$CC $CFLAGS -c jansi_structs.c
$CC $CFLAGS -c jansi_ttyname.c
$CC $CFLAGS $LDFLAGS -shared -o libjansi.so *.o -lutil
cd -

%mvn_build -- -Dlibrary.jansi.path=$PWD/src/main/native

%install
mkdir -p %{buildroot}%{_prefix}/lib/%{name}
cp -p src/main/native/libjansi.so %{buildroot}%{_prefix}/lib/%{name}

%mvn_install

%files -f .mfiles
%license license.txt
%doc readme.md changelog.md
%{_prefix}/lib/%{name}/

%files javadoc -f .mfiles-javadoc
%license license.txt

%changelog
* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.4.0-4
- Rebuilt for OpenCloudOS Stream 23.05

* Thu Apr 20 2023 Xiaojie Chen <jackxjchen@tencent.com> - 2.4.0-3
- Disable bootstrap

* Thu Apr 13 2023 Xiaojie Chen <jackxjchen@tencent.com> - 2.4.0-2
- Remove unused script

* Thu Apr 13 2023 Xiaojie Chen <jackxjchen@tencent.com> - 2.4.0-1
- Rewritten spec for maven 3.8.6
